@@ -40,7 +40,7 @@ using System.Runtime.CompilerServices;
 //
 // You can specify all values by your own or you can build default build and revision
 // numbers with the '*' character (the default):
-[assembly: AssemblyVersion("0.9.0.0")]
+[assembly: AssemblyVersion("0.10.0.0")]
 
 // The following attributes specify the key for the sign of your assembly. See the
 // .NET Framework documentation for more information about signing.
@@ -52,9 +52,9 @@ namespace Do
 {
 	internal static class AssemblyInfo
 	{
-		public const string DisplayVersion = "0.8.4";
-		public const string VersionDetails = "bzr trunk r1331";
-		public const string LocaleDirectory = "/usr/local/share/locale";
+		public const string DisplayVersion = "0.8.5";
+		public const string VersionDetails = "bzr trunk r1348";
+		public const string LocaleDirectory = "/home/chris/.local/share/locale";
 	}
 }
 
